# Changelog

## [0.4.1](https://github.com/b1rger/django-json-editor-field/compare/v0.4.0...v0.4.1) (2025-02-05)


### Bug Fixes

* **field:** copy the options dict so it does not get reused ([6af25e6](https://github.com/b1rger/django-json-editor-field/commit/6af25e6c5effd61c3f6dbc803d9d3013ca3a3b32))

## [0.4.0](https://github.com/b1rger/django-json-editor-field/compare/v0.3.0...v0.4.0) (2024-12-10)


### Features

* implement backend schema validation ([893b39a](https://github.com/b1rger/django-json-editor-field/commit/893b39ab38fd526fa7a0da79445ff5274b719baa))
* loose the custom default settings ([82517f2](https://github.com/b1rger/django-json-editor-field/commit/82517f29c4134b40127faf70821006e8c990daee))


### Documentation

* add more information to the readme ([1f207a4](https://github.com/b1rger/django-json-editor-field/commit/1f207a465e672f919ee9229db0112b8bfd042be8))

## [0.3.0](https://github.com/b1rger/django-json-editor-field/compare/v0.2.1...v0.3.0) (2024-12-10)


### Features

* use textarea template instead of input template ([20b7d41](https://github.com/b1rger/django-json-editor-field/commit/20b7d410535d7ddf1cc17a6f7ecd22e59bc6f478))


### Bug Fixes

* **field:** set field to allow blank values by default ([3c8b9db](https://github.com/b1rger/django-json-editor-field/commit/3c8b9db3fdd89773801cb8f6858efb75dc02836d))
* **js:** only set value editor value if there is a value ([6613d63](https://github.com/b1rger/django-json-editor-field/commit/6613d6342ceb537b03967cb52e65cfe3e3036d6c))

## [0.2.1](https://github.com/b1rger/django-json-editor-field/compare/v0.2.0...v0.2.1) (2024-12-09)


### Miscellaneous Chores

* release 0.2.1 ([7afaa50](https://github.com/b1rger/django-json-editor-field/commit/7afaa5037ddafd65c2a8855802d394c835e946c5))

## 0.2.0 (2024-12-09)


### Features

* add gitignore file ([6dab826](https://github.com/b1rger/django-json-editor-field/commit/6dab82611fb5a049737e413979c3408c0d5416aa))
* allow to pass options to the JSONEditor ([a46bece](https://github.com/b1rger/django-json-editor-field/commit/a46beceee6b998a617c9611af8aa040702d95ab9))


### Miscellaneous Chores

* release 0.2.0 ([b3f02da](https://github.com/b1rger/django-json-editor-field/commit/b3f02da440a37762231c04bc6f786550b0530249))
